@@ -297,7 +297,7 @@ void FileModel::setupModelData(const QList<QUrl> &files)
     foreach (const QUrl &file, files)
     {
         FileItem *parent = m_rootItem;
-        QStringList directories = file.toLocalFile().remove(destDirectory).split('/', QString::SkipEmptyParts);
+        QStringList directories = file.toLocalFile().remove(destDirectory).split('/', Qt::SkipEmptyParts);
         FileItem *child = nullptr;
         while (directories.count())
         {
@@ -349,13 +349,13 @@ QVariant FileModel::data(const QModelIndex &index, int role) const
     }
 
 
-    FileItem *item = static_cast<FileItem*>(index.internalPointer());
+    auto *item = static_cast<FileItem*>(index.internalPointer());
     const QVariant data = item->data(index.column(), role);
 
     //get the status icon as well as status text
     if (index.column() == FileItem::Status)
     {
-        const Job::Status status = static_cast<Job::Status>(data.toInt());
+        const auto status = static_cast<Job::Status>(data.toInt());
         if (item->isFile()) {
             if (role == Qt::DisplayRole)
             {
@@ -376,7 +376,7 @@ QVariant FileModel::data(const QModelIndex &index, int role) const
                 }
                 else
                 {
-                    return Transfer::statusPixmap(status);
+                    return QIcon::fromTheme(Transfer::statusIconName(status));
                 }
             }
         } else {
@@ -394,7 +394,7 @@ bool FileModel::setData(const QModelIndex &index, const QVariant &value, int rol
         return false;
     }
 
-    FileItem *item = static_cast<FileItem*>(index.internalPointer());
+    auto *item = static_cast<FileItem*>(index.internalPointer());
 
     if ((index.column() == FileItem::File) && (role == Qt::CheckStateRole)) {
         const bool worked = item->setData(index.column(), value, this, role);
@@ -491,7 +491,7 @@ QModelIndex FileModel::parent(const QModelIndex &index) const
         return QModelIndex();
     }
 
-    FileItem *childItem = static_cast<FileItem*>(index.internalPointer());
+    auto *childItem = static_cast<FileItem*>(index.internalPointer());
     FileItem *parentItem = childItem->parent();
     if ((parentItem == m_rootItem) || (!parentItem))
     {
@@ -526,11 +526,11 @@ int FileModel::rowCount(const QModelIndex &parent) const
 void FileModel::changeData(int row, int column, FileItem *item, bool finished)
 {
     QModelIndex index = createIndex(row, column, item);
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
 
     if (finished) {
         const QUrl file = getUrl(index);
-        emit fileFinished(file);
+        Q_EMIT fileFinished(file);
     }
 }
 
@@ -585,7 +585,7 @@ FileItem *FileModel::getItem(const QUrl &file)
     QString destDirectory = m_destDirectory.toLocalFile();
 
     FileItem *item = m_rootItem;
-    QStringList directories = file.toLocalFile().remove(destDirectory).split('/', QString::SkipEmptyParts);
+    QStringList directories = file.toLocalFile().remove(destDirectory).split('/', Qt::SkipEmptyParts);
     while (directories.count())
     {
         QString part = directories.takeFirst();
@@ -609,7 +609,7 @@ FileItem *FileModel::getItem(const QUrl &file)
 
     if (item == m_rootItem)
     {
-        item = 0;
+        item = nullptr;
     }
     else
     {
@@ -640,7 +640,7 @@ bool FileModel::isFile(const QModelIndex &index) const
         return false;
     }
 
-    FileItem *item = static_cast<FileItem*>(index.internalPointer());
+    auto *item = static_cast<FileItem*>(index.internalPointer());
 
     //only files can be renamed, no folders
     return item->isFile();
@@ -653,7 +653,7 @@ void FileModel::rename(const QModelIndex &file, const QString &newName)
         return;
     }
 
-    FileItem *item = static_cast<FileItem*>(file.internalPointer());
+    auto *item = static_cast<FileItem*>(file.internalPointer());
     //only files can be renamed, no folders
     if (!item->isFile()) {
         return;
@@ -672,7 +672,7 @@ void FileModel::rename(const QModelIndex &file, const QString &newName)
 
     setData(file, newName);
 
-    emit rename(oldUrl, newUrl);
+    Q_EMIT rename(oldUrl, newUrl);
 }
 
 void FileModel::renameFailed(const QUrl &beforeRename, const QUrl &afterRename)
@@ -690,7 +690,7 @@ void FileModel::stopWatchCheckState()
 {
     if (m_checkStateChanged)
     {
-        emit checkStateChanged();
+        Q_EMIT checkStateChanged();
     }
 
     m_checkStateChanged = false;
